Amount

Struct Amount 

pub struct Amount<T: NumLike> {
    pub mol: T,
}
The amount unit type, defined as moles in SI units

Fields

mol: T

The value of this Amount in moles

Implementations

Source

impl<T> Amount<T>
where T: NumLike,

pub fn unit_name() -> &'static str

Returns the standard unit name of amount: “moles”

pub fn unit_symbol() -> &'static str

Returns the abbreviated name or symbol of amount: “mol” for moles

pub fn from_moles(moles: T) -> Self

Returns a new amount value from the given number of moles

Arguments
  • moles - Any number-like type, representing a quantity of moles
pub fn to_moles(&self) -> T

Returns a copy of this amount value in moles

pub fn from_mol(mol: T) -> Self

Returns a new amount value from the given number of moles

Arguments
  • mol - Any number-like type, representing a quantity of moles
pub fn to_mol(&self) -> T

Returns a copy of this amount value in moles

Source

impl<T> Amount<T>
where T: NumLike + From<f64>,

pub fn to_count(&self) -> T

Returns a copy of this amount value in count

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_count(count: T) -> Self

Returns a new amount value from the given number of count

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • count - Any number-like type, representing a quantity of count
pub fn to_mmol(&self) -> T

Returns a copy of this amount value in millimoles

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_mmol(mmol: T) -> Self

Returns a new amount value from the given number of millimoles

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • mmol - Any number-like type, representing a quantity of millimoles
pub fn to_umol(&self) -> T

Returns a copy of this amount value in micromoles

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_umol(umol: T) -> Self

Returns a new amount value from the given number of micromoles

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • umol - Any number-like type, representing a quantity of micromoles
pub fn to_nmol(&self) -> T

Returns a copy of this amount value in nanomoles

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_nmol(nmol: T) -> Self

Returns a new amount value from the given number of nanomoles

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • nmol - Any number-like type, representing a quantity of nanomoles
pub fn to_pmol(&self) -> T

Returns a copy of this amount value in picomoles

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_pmol(pmol: T) -> Self

Returns a new amount value from the given number of picomoles

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • pmol - Any number-like type, representing a quantity of picomoles