Current

Struct Current 

pub struct Current<T: NumLike> {
    pub A: T,
}
The electrical current unit type, defined as amperes in SI units

Fields

A: T

The value of this Electrical current in amperes

Implementations

Source

impl<T> Current<T>
where T: NumLike,

pub fn unit_name() -> &'static str

Returns the standard unit name of electrical current: “amperes”

pub fn unit_symbol() -> &'static str

Returns the abbreviated name or symbol of electrical current: “A” for amperes

pub fn from_A(A: T) -> Self

Returns a new electrical current value from the given number of amperes

Arguments
  • A - Any number-like type, representing a quantity of amperes
pub fn to_A(&self) -> T

Returns a copy of this electrical current value in amperes

pub fn from_amps(amps: T) -> Self

Returns a new electrical current value from the given number of amperes

Arguments
  • amps - Any number-like type, representing a quantity of amperes
pub fn to_amps(&self) -> T

Returns a copy of this electrical current value in amperes

Source

impl<T> Current<T>
where T: NumLike + From<f64>,

pub fn to_mA(&self) -> T

Returns a copy of this electrical current value in milliamperes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_mA(mA: T) -> Self

Returns a new electrical current value from the given number of milliamperes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • mA - Any number-like type, representing a quantity of milliamperes
pub fn to_uA(&self) -> T

Returns a copy of this electrical current value in microamperes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_uA(uA: T) -> Self

Returns a new electrical current value from the given number of microamperes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • uA - Any number-like type, representing a quantity of microamperes
pub fn to_nA(&self) -> T

Returns a copy of this electrical current value in nanoamperes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_nA(nA: T) -> Self

Returns a new electrical current value from the given number of nanoamperes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • nA - Any number-like type, representing a quantity of nanoamperes
pub fn to_kA(&self) -> T

Returns a copy of this electrical current value in kiloamperes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_kA(kA: T) -> Self

Returns a new electrical current value from the given number of kiloamperes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • kA - Any number-like type, representing a quantity of kiloamperes
pub fn to_MA(&self) -> T

Returns a copy of this electrical current value in megaamperes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_MA(MA: T) -> Self

Returns a new electrical current value from the given number of megaamperes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • MA - Any number-like type, representing a quantity of megaamperes
pub fn to_GA(&self) -> T

Returns a copy of this electrical current value in gigaamperes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_GA(GA: T) -> Self

Returns a new electrical current value from the given number of gigaamperes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • GA - Any number-like type, representing a quantity of gigaamperes