Distance

Struct Distance 

pub struct Distance<T: NumLike> {
    pub m: T,
}
The distance (aka length) unit type, defined as meters in SI units

Fields

m: T

The value of this Distance in meters

Implementations

Source

impl<T> Distance<T>
where T: NumLike,

pub fn unit_name() -> &'static str

Returns the standard unit name of distance: “meters”

pub fn unit_symbol() -> &'static str

Returns the abbreviated name or symbol of distance: “m” for meters

pub fn from_m(m: T) -> Self

Returns a new distance value from the given number of meters

Arguments
  • m - Any number-like type, representing a quantity of meters
pub fn to_m(&self) -> T

Returns a copy of this distance value in meters

pub fn from_meters(meters: T) -> Self

Returns a new distance value from the given number of meters

Arguments
  • meters - Any number-like type, representing a quantity of meters
pub fn to_meters(&self) -> T

Returns a copy of this distance value in meters

Source

impl<T> Distance<T>
where T: NumLike + From<f64>,

pub fn to_cm(&self) -> T

Returns a copy of this distance value in millimeters

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_cm(cm: T) -> Self

Returns a new distance value from the given number of millimeters

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • cm - Any number-like type, representing a quantity of millimeters
pub fn to_mm(&self) -> T

Returns a copy of this distance value in millimeters

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_mm(mm: T) -> Self

Returns a new distance value from the given number of millimeters

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • mm - Any number-like type, representing a quantity of millimeters
pub fn to_um(&self) -> T

Returns a copy of this distance value in micrometers

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_um(um: T) -> Self

Returns a new distance value from the given number of micrometers

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • um - Any number-like type, representing a quantity of micrometers
pub fn to_nm(&self) -> T

Returns a copy of this distance value in nanometers

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_nm(nm: T) -> Self

Returns a new distance value from the given number of nanometers

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • nm - Any number-like type, representing a quantity of nanometers
pub fn to_pm(&self) -> T

Returns a copy of this distance value in picometers

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_pm(pm: T) -> Self

Returns a new distance value from the given number of picometers

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • pm - Any number-like type, representing a quantity of picometers
pub fn to_km(&self) -> T

Returns a copy of this distance value in kilometers

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_km(km: T) -> Self

Returns a new distance value from the given number of kilometers

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • km - Any number-like type, representing a quantity of kilometers
pub fn to_au(&self) -> T

Returns a copy of this distance value in astronomical units

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_au(au: T) -> Self

Returns a new distance value from the given number of astronomical units

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • au - Any number-like type, representing a quantity of astronomical units
pub fn to_parsec(&self) -> T

Returns a copy of this distance value in parsecs

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_parsec(parsec: T) -> Self

Returns a new distance value from the given number of parsecs

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • parsec - Any number-like type, representing a quantity of parsecs
pub fn to_lyr(&self) -> T

Returns a copy of this distance value in light-years

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_lyr(lyr: T) -> Self

Returns a new distance value from the given number of light-years

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • lyr - Any number-like type, representing a quantity of light-years