InverseAmount

Struct InverseAmount 

pub struct InverseAmount<T: NumLike> {
    pub per_mol: T,
}
The inverse of amount unit type, defined as inverse moles in SI units

Fields

per_mol: T

The value of this Inverse amount in inverse moles

Implementations

Source

impl<T> InverseAmount<T>
where T: NumLike,

pub fn unit_name() -> &'static str

Returns the standard unit name of inverse amount: “inverse moles”

pub fn unit_symbol() -> &'static str

Returns the abbreviated name or symbol of inverse amount: “1/mol” for inverse moles

pub fn from_per_mole(per_mole: T) -> Self

Returns a new inverse amount value from the given number of inverse moles

Arguments
  • per_mole - Any number-like type, representing a quantity of inverse moles
pub fn to_per_mole(&self) -> T

Returns a copy of this inverse amount value in inverse moles

pub fn from_per_mol(per_mol: T) -> Self

Returns a new inverse amount value from the given number of inverse moles

Arguments
  • per_mol - Any number-like type, representing a quantity of inverse moles
pub fn to_per_mol(&self) -> T

Returns a copy of this inverse amount value in inverse moles

Source

impl<T> InverseAmount<T>
where T: NumLike + From<f64>,

pub fn to_per_count(&self) -> T

Returns a copy of this inverse amount value in inverse count

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_count(per_count: T) -> Self

Returns a new inverse amount value from the given number of inverse count

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_count - Any number-like type, representing a quantity of inverse count
pub fn to_per_mmol(&self) -> T

Returns a copy of this inverse amount value in inverse millimoles

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_mmol(per_mmol: T) -> Self

Returns a new inverse amount value from the given number of inverse millimoles

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_mmol - Any number-like type, representing a quantity of inverse millimoles
pub fn to_per_umol(&self) -> T

Returns a copy of this inverse amount value in inverse micromoles

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_umol(per_umol: T) -> Self

Returns a new inverse amount value from the given number of inverse micromoles

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_umol - Any number-like type, representing a quantity of inverse micromoles
pub fn to_per_nmol(&self) -> T

Returns a copy of this inverse amount value in inverse nanomoles

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_nmol(per_nmol: T) -> Self

Returns a new inverse amount value from the given number of inverse nanomoles

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_nmol - Any number-like type, representing a quantity of inverse nanomoles
pub fn to_per_pmol(&self) -> T

Returns a copy of this inverse amount value in inverse picomoles

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_pmol(per_pmol: T) -> Self

Returns a new inverse amount value from the given number of inverse picomoles

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_pmol - Any number-like type, representing a quantity of inverse picomoles