InverseCurrent

Struct InverseCurrent 

pub struct InverseCurrent<T: NumLike> {
    pub per_A: T,
}
The inverse of electrical current unit type, defined as inverse amperes in SI units

Fields

per_A: T

The value of this Inverse electrical current in inverse amperes

Implementations

Source

impl<T> InverseCurrent<T>
where T: NumLike,

pub fn unit_name() -> &'static str

Returns the standard unit name of inverse electrical current: “inverse amperes”

pub fn unit_symbol() -> &'static str

Returns the abbreviated name or symbol of inverse electrical current: “1/A” for inverse amperes

pub fn from_per_A(per_A: T) -> Self

Returns a new inverse electrical current value from the given number of inverse amperes

Arguments
  • per_A - Any number-like type, representing a quantity of inverse amperes
pub fn to_per_A(&self) -> T

Returns a copy of this inverse electrical current value in inverse amperes

pub fn from_per_ampere(per_ampere: T) -> Self

Returns a new inverse electrical current value from the given number of inverse amperes

Arguments
  • per_ampere - Any number-like type, representing a quantity of inverse amperes
pub fn to_per_ampere(&self) -> T

Returns a copy of this inverse electrical current value in inverse amperes

Source

impl<T> InverseCurrent<T>
where T: NumLike + From<f64>,

pub fn to_per_mA(&self) -> T

Returns a copy of this inverse electrical current value in inverse milliamperes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_mA(per_mA: T) -> Self

Returns a new inverse electrical current value from the given number of inverse milliamperes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_mA - Any number-like type, representing a quantity of inverse milliamperes
pub fn to_per_uA(&self) -> T

Returns a copy of this inverse electrical current value in inverse microamperes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_uA(per_uA: T) -> Self

Returns a new inverse electrical current value from the given number of inverse microamperes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_uA - Any number-like type, representing a quantity of inverse microamperes
pub fn to_per_nA(&self) -> T

Returns a copy of this inverse electrical current value in inverse nanoamperes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_nA(per_nA: T) -> Self

Returns a new inverse electrical current value from the given number of inverse nanoamperes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_nA - Any number-like type, representing a quantity of inverse nanoamperes
pub fn to_per_kA(&self) -> T

Returns a copy of this inverse electrical current value in inverse kiloamperes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_kA(per_kA: T) -> Self

Returns a new inverse electrical current value from the given number of inverse kiloamperes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_kA - Any number-like type, representing a quantity of inverse kiloamperes
pub fn to_per_MA(&self) -> T

Returns a copy of this inverse electrical current value in inverse megaamperes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_MA(per_MA: T) -> Self

Returns a new inverse electrical current value from the given number of inverse megaamperes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_MA - Any number-like type, representing a quantity of inverse megaamperes
pub fn to_per_GA(&self) -> T

Returns a copy of this inverse electrical current value in inverse gigaamperes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_GA(per_GA: T) -> Self

Returns a new inverse electrical current value from the given number of inverse gigaamperes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_GA - Any number-like type, representing a quantity of inverse gigaamperes