InverseMass

Struct InverseMass 

pub struct InverseMass<T: NumLike> {
    pub per_kg: T,
}
The inverse of mass unit type, defined as inverse kilograms in SI units

Fields

per_kg: T

The value of this Inverse mass in inverse kilograms

Implementations

Source

impl<T> InverseMass<T>
where T: NumLike,

pub fn unit_name() -> &'static str

Returns the standard unit name of inverse mass: “inverse kilograms”

pub fn unit_symbol() -> &'static str

Returns the abbreviated name or symbol of inverse mass: “1/kg” for inverse kilograms

pub fn from_per_kg(per_kg: T) -> Self

Returns a new inverse mass value from the given number of inverse kilograms

Arguments
  • per_kg - Any number-like type, representing a quantity of inverse kilograms
pub fn to_per_kg(&self) -> T

Returns a copy of this inverse mass value in inverse kilograms

pub fn from_per_kilograms(per_kilograms: T) -> Self

Returns a new inverse mass value from the given number of inverse kilograms

Arguments
  • per_kilograms - Any number-like type, representing a quantity of inverse kilograms
pub fn to_per_kilograms(&self) -> T

Returns a copy of this inverse mass value in inverse kilograms

Source

impl<T> InverseMass<T>
where T: NumLike + From<f64>,

pub fn to_per_g(&self) -> T

Returns a copy of this inverse mass value in inverse grams

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_g(per_g: T) -> Self

Returns a new inverse mass value from the given number of inverse grams

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_g - Any number-like type, representing a quantity of inverse grams
pub fn to_per_mg(&self) -> T

Returns a copy of this inverse mass value in inverse milligrams

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_mg(per_mg: T) -> Self

Returns a new inverse mass value from the given number of inverse milligrams

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_mg - Any number-like type, representing a quantity of inverse milligrams
pub fn to_per_ug(&self) -> T

Returns a copy of this inverse mass value in inverse micrograms

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_ug(per_ug: T) -> Self

Returns a new inverse mass value from the given number of inverse micrograms

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_ug - Any number-like type, representing a quantity of inverse micrograms
pub fn to_per_ng(&self) -> T

Returns a copy of this inverse mass value in inverse nanograms

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_ng(per_ng: T) -> Self

Returns a new inverse mass value from the given number of inverse nanograms

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_ng - Any number-like type, representing a quantity of inverse nanograms
pub fn to_per_pg(&self) -> T

Returns a copy of this inverse mass value in inverse picograms

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_pg(per_pg: T) -> Self

Returns a new inverse mass value from the given number of inverse picograms

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_pg - Any number-like type, representing a quantity of inverse picograms
pub fn to_per_tons(&self) -> T

Returns a copy of this inverse mass value in inverse tons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_tons(per_tons: T) -> Self

Returns a new inverse mass value from the given number of inverse tons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_tons - Any number-like type, representing a quantity of inverse tons
pub fn to_per_earth_mass(&self) -> T

Returns a copy of this inverse mass value in inverse earth masses

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_earth_mass(per_earth_mass: T) -> Self

Returns a new inverse mass value from the given number of inverse earth masses

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_earth_mass - Any number-like type, representing a quantity of inverse earth masses
pub fn to_per_jupiter_mass(&self) -> T

Returns a copy of this inverse mass value in inverse jupiter masses

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_jupiter_mass(per_jupiter_mass: T) -> Self

Returns a new inverse mass value from the given number of inverse jupiter masses

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_jupiter_mass - Any number-like type, representing a quantity of inverse jupiter masses
pub fn to_per_solar_mass(&self) -> T

Returns a copy of this inverse mass value in inverse solar masses

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_solar_mass(per_solar_mass: T) -> Self

Returns a new inverse mass value from the given number of inverse solar masses

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_solar_mass - Any number-like type, representing a quantity of inverse solar masses