Mass

Struct Mass 

pub struct Mass<T: NumLike> {
    pub kg: T,
}
The mass unit type, defined as kilograms in SI units

Fields

kg: T

The value of this Mass in kilograms

Implementations

Source

impl<T> Mass<T>
where T: NumLike,

pub fn unit_name() -> &'static str

Returns the standard unit name of mass: “kilograms”

pub fn unit_symbol() -> &'static str

Returns the abbreviated name or symbol of mass: “kg” for kilograms

pub fn from_kg(kg: T) -> Self

Returns a new mass value from the given number of kilograms

Arguments
  • kg - Any number-like type, representing a quantity of kilograms
pub fn to_kg(&self) -> T

Returns a copy of this mass value in kilograms

pub fn from_kilograms(kilograms: T) -> Self

Returns a new mass value from the given number of kilograms

Arguments
  • kilograms - Any number-like type, representing a quantity of kilograms
pub fn to_kilograms(&self) -> T

Returns a copy of this mass value in kilograms

Source

impl<T> Mass<T>
where T: NumLike + From<f64>,

pub fn to_g(&self) -> T

Returns a copy of this mass value in grams

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_g(g: T) -> Self

Returns a new mass value from the given number of grams

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • g - Any number-like type, representing a quantity of grams
pub fn to_mg(&self) -> T

Returns a copy of this mass value in milligrams

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_mg(mg: T) -> Self

Returns a new mass value from the given number of milligrams

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • mg - Any number-like type, representing a quantity of milligrams
pub fn to_ug(&self) -> T

Returns a copy of this mass value in micrograms

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_ug(ug: T) -> Self

Returns a new mass value from the given number of micrograms

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • ug - Any number-like type, representing a quantity of micrograms
pub fn to_ng(&self) -> T

Returns a copy of this mass value in nanograms

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_ng(ng: T) -> Self

Returns a new mass value from the given number of nanograms

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • ng - Any number-like type, representing a quantity of nanograms
pub fn to_pg(&self) -> T

Returns a copy of this mass value in picograms

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_pg(pg: T) -> Self

Returns a new mass value from the given number of picograms

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • pg - Any number-like type, representing a quantity of picograms
pub fn to_tons(&self) -> T

Returns a copy of this mass value in tons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_tons(tons: T) -> Self

Returns a new mass value from the given number of tons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • tons - Any number-like type, representing a quantity of tons
pub fn to_earth_mass(&self) -> T

Returns a copy of this mass value in earth masses

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_earth_mass(earth_mass: T) -> Self

Returns a new mass value from the given number of earth masses

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • earth_mass - Any number-like type, representing a quantity of earth masses
pub fn to_jupiter_mass(&self) -> T

Returns a copy of this mass value in jupiter masses

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_jupiter_mass(jupiter_mass: T) -> Self

Returns a new mass value from the given number of jupiter masses

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • jupiter_mass - Any number-like type, representing a quantity of jupiter masses
pub fn to_solar_mass(&self) -> T

Returns a copy of this mass value in solar masses

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_solar_mass(solar_mass: T) -> Self

Returns a new mass value from the given number of solar masses

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • solar_mass - Any number-like type, representing a quantity of solar masses