Temperature

Struct Temperature 

pub struct Temperature<T: NumLike> {
    pub K: T,
}
The temperature unit type, defined as degrees kelvin in SI units

Fields

K: T

The value of this Temperature in degrees kelvin

Implementations

Source

impl<T> Temperature<T>
where T: NumLike,

pub fn unit_name() -> &'static str

Returns the standard unit name of temperature: “degrees kelvin”

pub fn unit_symbol() -> &'static str

Returns the abbreviated name or symbol of temperature: “K” for degrees kelvin

pub fn from_K(K: T) -> Self

Returns a new temperature value from the given number of degrees kelvin

Arguments
  • K - Any number-like type, representing a quantity of degrees kelvin
pub fn to_K(&self) -> T

Returns a copy of this temperature value in degrees kelvin

Source

impl<T> Temperature<T>
where T: NumLike + From<f64>,

pub fn to_C(&self) -> T

Returns a copy of this temperature value in degrees celsius

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_C(C: T) -> Self

Returns a new temperature value from the given number of degrees celsius

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • C - Any number-like type, representing a quantity of degrees celsius
pub fn to_celsius(&self) -> T

Returns a copy of this temperature value in degrees celsius

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_celsius(celsius: T) -> Self

Returns a new temperature value from the given number of degrees celsius

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • celsius - Any number-like type, representing a quantity of degrees celsius
pub fn to_F(&self) -> T

Returns a copy of this temperature value in degrees fahrenheit

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_F(F: T) -> Self

Returns a new temperature value from the given number of degrees fahrenheit

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • F - Any number-like type, representing a quantity of degrees fahrenheit