Time

Struct Time 

pub struct Time<T: NumLike> {
    pub s: T,
}
The time unit type, defined as seconds in SI units

Fields

s: T

The value of this Time in seconds

Implementations

Source

impl<T> Time<T>
where T: NumLike,

pub fn unit_name() -> &'static str

Returns the standard unit name of time: “seconds”

pub fn unit_symbol() -> &'static str

Returns the abbreviated name or symbol of time: “s” for seconds

pub fn from_s(s: T) -> Self

Returns a new time value from the given number of seconds

Arguments
  • s - Any number-like type, representing a quantity of seconds
pub fn to_s(&self) -> T

Returns a copy of this time value in seconds

pub fn from_seconds(seconds: T) -> Self

Returns a new time value from the given number of seconds

Arguments
  • seconds - Any number-like type, representing a quantity of seconds
pub fn to_seconds(&self) -> T

Returns a copy of this time value in seconds

Source

impl<T> Time<T>
where T: NumLike + From<f64>,

pub fn to_ms(&self) -> T

Returns a copy of this time value in milliseconds

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_ms(ms: T) -> Self

Returns a new time value from the given number of milliseconds

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • ms - Any number-like type, representing a quantity of milliseconds
pub fn to_us(&self) -> T

Returns a copy of this time value in microseconds

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_us(us: T) -> Self

Returns a new time value from the given number of microseconds

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • us - Any number-like type, representing a quantity of microseconds
pub fn to_ns(&self) -> T

Returns a copy of this time value in nanoseconds

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_ns(ns: T) -> Self

Returns a new time value from the given number of nanoseconds

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • ns - Any number-like type, representing a quantity of nanoseconds
pub fn to_ps(&self) -> T

Returns a copy of this time value in picoseconds

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_ps(ps: T) -> Self

Returns a new time value from the given number of picoseconds

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • ps - Any number-like type, representing a quantity of picoseconds
pub fn to_min(&self) -> T

Returns a copy of this time value in minutes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_min(min: T) -> Self

Returns a new time value from the given number of minutes

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • min - Any number-like type, representing a quantity of minutes
pub fn to_hr(&self) -> T

Returns a copy of this time value in hours

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_hr(hr: T) -> Self

Returns a new time value from the given number of hours

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • hr - Any number-like type, representing a quantity of hours
pub fn to_days(&self) -> T

Returns a copy of this time value in days

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_days(days: T) -> Self

Returns a new time value from the given number of days

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • days - Any number-like type, representing a quantity of days
pub fn to_weeks(&self) -> T

Returns a copy of this time value in weeks

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_weeks(weeks: T) -> Self

Returns a new time value from the given number of weeks

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • weeks - Any number-like type, representing a quantity of weeks
pub fn to_yr(&self) -> T

Returns a copy of this time value in years

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_yr(yr: T) -> Self

Returns a new time value from the given number of years

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • yr - Any number-like type, representing a quantity of years
pub fn to_kyr(&self) -> T

Returns a copy of this time value in millennia

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_kyr(kyr: T) -> Self

Returns a new time value from the given number of millennia

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • kyr - Any number-like type, representing a quantity of millennia
pub fn to_Myr(&self) -> T

Returns a copy of this time value in million years

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_Myr(Myr: T) -> Self

Returns a new time value from the given number of million years

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • Myr - Any number-like type, representing a quantity of million years
pub fn to_Gyr(&self) -> T

Returns a copy of this time value in billion years

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_Gyr(Gyr: T) -> Self

Returns a new time value from the given number of billion years

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • Gyr - Any number-like type, representing a quantity of billion years