Angle

Struct Angle 

pub struct Angle<T: NumLike> {
    pub rad: T,
}
The angle unit type, defined as radians in SI units

Fields

rad: T

The value of this Angle in radians

Implementations

Source

impl<T> Angle<T>
where T: NumLike,

pub fn unit_name() -> &'static str

Returns the standard unit name of angle: “radians”

pub fn unit_symbol() -> &'static str

Returns the abbreviated name or symbol of angle: “rad” for radians

pub fn from_rad(rad: T) -> Self

Returns a new angle value from the given number of radians

Arguments
  • rad - Any number-like type, representing a quantity of radians
pub fn to_rad(&self) -> T

Returns a copy of this angle value in radians

pub fn from_radians(radians: T) -> Self

Returns a new angle value from the given number of radians

Arguments
  • radians - Any number-like type, representing a quantity of radians
pub fn to_radians(&self) -> T

Returns a copy of this angle value in radians

Source

impl<T> Angle<T>
where T: NumLike + From<f64>,

pub fn to_degrees(&self) -> T

Returns a copy of this angle value in degrees

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_degrees(degrees: T) -> Self

Returns a new angle value from the given number of degrees

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • degrees - Any number-like type, representing a quantity of degrees
pub fn to_deg(&self) -> T

Returns a copy of this angle value in degrees

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_deg(deg: T) -> Self

Returns a new angle value from the given number of degrees

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • deg - Any number-like type, representing a quantity of degrees