Area

Struct Area 

pub struct Area<T: NumLike> {
    pub m2: T,
}
The area unit type, defined as square meters in SI units

Fields

m2: T

The value of this Area in square meters

Implementations

Source

impl<T> Area<T>
where T: NumLike,

pub fn unit_name() -> &'static str

Returns the standard unit name of area: “square meters”

pub fn unit_symbol() -> &'static str

Returns the abbreviated name or symbol of area: “m²” for square meters

pub fn from_m2(m2: T) -> Self

Returns a new area value from the given number of square meters

Arguments
  • m2 - Any number-like type, representing a quantity of square meters
pub fn to_m2(&self) -> T

Returns a copy of this area value in square meters

pub fn from_square_meters(square_meters: T) -> Self

Returns a new area value from the given number of square meters

Arguments
  • square_meters - Any number-like type, representing a quantity of square meters
pub fn to_square_meters(&self) -> T

Returns a copy of this area value in square meters

Source

impl<T> Area<T>
where T: NumLike + From<f64>,

pub fn to_cm2(&self) -> T

Returns a copy of this area value in square cm

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_cm2(cm2: T) -> Self

Returns a new area value from the given number of square cm

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • cm2 - Any number-like type, representing a quantity of square cm
pub fn to_square_cm(&self) -> T

Returns a copy of this area value in square cm

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_square_cm(square_cm: T) -> Self

Returns a new area value from the given number of square cm

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • square_cm - Any number-like type, representing a quantity of square cm
pub fn to_mm2(&self) -> T

Returns a copy of this area value in square mm

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_mm2(mm2: T) -> Self

Returns a new area value from the given number of square mm

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • mm2 - Any number-like type, representing a quantity of square mm
pub fn to_um2(&self) -> T

Returns a copy of this area value in square um

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_um2(um2: T) -> Self

Returns a new area value from the given number of square um

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • um2 - Any number-like type, representing a quantity of square um
pub fn to_nm2(&self) -> T

Returns a copy of this area value in square nm

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_nm2(nm2: T) -> Self

Returns a new area value from the given number of square nm

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • nm2 - Any number-like type, representing a quantity of square nm
pub fn to_km2(&self) -> T

Returns a copy of this area value in square km

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_km2(km2: T) -> Self

Returns a new area value from the given number of square km

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • km2 - Any number-like type, representing a quantity of square km