InverseArea

Struct InverseArea 

pub struct InverseArea<T: NumLike> {
    pub per_m2: T,
}
The inverse of area unit type, defined as inverse square meters in SI units

Fields

per_m2: T

The value of this Inverse area in inverse square meters

Implementations

Source

impl<T> InverseArea<T>
where T: NumLike,

pub fn unit_name() -> &'static str

Returns the standard unit name of inverse area: “inverse square meters”

pub fn unit_symbol() -> &'static str

Returns the abbreviated name or symbol of inverse area: “1/m²” for inverse square meters

pub fn from_per_m2(per_m2: T) -> Self

Returns a new inverse area value from the given number of inverse square meters

Arguments
  • per_m2 - Any number-like type, representing a quantity of inverse square meters
pub fn to_per_m2(&self) -> T

Returns a copy of this inverse area value in inverse square meters

pub fn from_per_square_meter(per_square_meter: T) -> Self

Returns a new inverse area value from the given number of inverse square meters

Arguments
  • per_square_meter - Any number-like type, representing a quantity of inverse square meters
pub fn to_per_square_meter(&self) -> T

Returns a copy of this inverse area value in inverse square meters

Source

impl<T> InverseArea<T>
where T: NumLike + From<f64>,

pub fn to_per_cm2(&self) -> T

Returns a copy of this inverse area value in inverse square cm

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_cm2(per_cm2: T) -> Self

Returns a new inverse area value from the given number of inverse square cm

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_cm2 - Any number-like type, representing a quantity of inverse square cm
pub fn to_per_square_cm(&self) -> T

Returns a copy of this inverse area value in inverse square cm

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_square_cm(per_square_cm: T) -> Self

Returns a new inverse area value from the given number of inverse square cm

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_square_cm - Any number-like type, representing a quantity of inverse square cm
pub fn to_per_mm2(&self) -> T

Returns a copy of this inverse area value in inverse square mm

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_mm2(per_mm2: T) -> Self

Returns a new inverse area value from the given number of inverse square mm

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_mm2 - Any number-like type, representing a quantity of inverse square mm
pub fn to_per_um2(&self) -> T

Returns a copy of this inverse area value in inverse square um

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_um2(per_um2: T) -> Self

Returns a new inverse area value from the given number of inverse square um

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_um2 - Any number-like type, representing a quantity of inverse square um
pub fn to_per_nm2(&self) -> T

Returns a copy of this inverse area value in inverse square nm

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_nm2(per_nm2: T) -> Self

Returns a new inverse area value from the given number of inverse square nm

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_nm2 - Any number-like type, representing a quantity of inverse square nm
pub fn to_per_km2(&self) -> T

Returns a copy of this inverse area value in inverse square km

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_km2(per_km2: T) -> Self

Returns a new inverse area value from the given number of inverse square km

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_km2 - Any number-like type, representing a quantity of inverse square km