Volume

Struct Volume 

pub struct Volume<T: NumLike> {
    pub m3: T,
}
The volume unit type, defined as cubic meters in SI units

Fields

m3: T

The value of this Volume in cubic meters

Implementations

Source

impl<T> Volume<T>
where T: NumLike,

pub fn unit_name() -> &'static str

Returns the standard unit name of volume: “cubic meters”

pub fn unit_symbol() -> &'static str

Returns the abbreviated name or symbol of volume: “m³” for cubic meters

pub fn from_m3(m3: T) -> Self

Returns a new volume value from the given number of cubic meters

Arguments
  • m3 - Any number-like type, representing a quantity of cubic meters
pub fn to_m3(&self) -> T

Returns a copy of this volume value in cubic meters

pub fn from_cubic_meters(cubic_meters: T) -> Self

Returns a new volume value from the given number of cubic meters

Arguments
  • cubic_meters - Any number-like type, representing a quantity of cubic meters
pub fn to_cubic_meters(&self) -> T

Returns a copy of this volume value in cubic meters

pub fn from_kL(kL: T) -> Self

Returns a new volume value from the given number of kiloliters

Arguments
  • kL - Any number-like type, representing a quantity of cubic meters
pub fn to_kL(&self) -> T

Returns a copy of this volume value in kiloliters

Source

impl<T> Volume<T>
where T: NumLike + From<f64>,

pub fn to_cc(&self) -> T

Returns a copy of this volume value in cubic cm

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_cc(cc: T) -> Self

Returns a new volume value from the given number of cubic cm

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • cc - Any number-like type, representing a quantity of cubic cm
pub fn to_L(&self) -> T

Returns a copy of this volume value in liters

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_L(L: T) -> Self

Returns a new volume value from the given number of liters

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • L - Any number-like type, representing a quantity of liters
pub fn to_liters(&self) -> T

Returns a copy of this volume value in liters

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_liters(liters: T) -> Self

Returns a new volume value from the given number of liters

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • liters - Any number-like type, representing a quantity of liters
pub fn to_mL(&self) -> T

Returns a copy of this volume value in milliliters

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_mL(mL: T) -> Self

Returns a new volume value from the given number of milliliters

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • mL - Any number-like type, representing a quantity of milliliters
pub fn to_uL(&self) -> T

Returns a copy of this volume value in microliters

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_uL(uL: T) -> Self

Returns a new volume value from the given number of microliters

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • uL - Any number-like type, representing a quantity of microliters
pub fn to_nL(&self) -> T

Returns a copy of this volume value in nanoliters

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_nL(nL: T) -> Self

Returns a new volume value from the given number of nanoliters

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • nL - Any number-like type, representing a quantity of nanoliters
pub fn to_pL(&self) -> T

Returns a copy of this volume value in picoliters

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_pL(pL: T) -> Self

Returns a new volume value from the given number of picoliters

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • pL - Any number-like type, representing a quantity of picoliters
pub fn to_ML(&self) -> T

Returns a copy of this volume value in megaliters

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_ML(ML: T) -> Self

Returns a new volume value from the given number of megaliters

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • ML - Any number-like type, representing a quantity of megaliters
pub fn to_GL(&self) -> T

Returns a copy of this volume value in gigaliters

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_GL(GL: T) -> Self

Returns a new volume value from the given number of gigaliters

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • GL - Any number-like type, representing a quantity of gigaliters