Acceleration

Struct Acceleration 

pub struct Acceleration<T: NumLike> {
    pub mps2: T,
}
The acceleration unit type, defined as meters per second squared in SI units

Fields

mps2: T

The value of this Acceleration in meters per second squared

Implementations

Source

impl<T> Acceleration<T>
where T: NumLike,

pub fn unit_name() -> &'static str

Returns the standard unit name of acceleration: “meters per second squared”

pub fn unit_symbol() -> &'static str

Returns the abbreviated name or symbol of acceleration: “m/s²” for meters per second squared

pub fn from_mps2(mps2: T) -> Self

Returns a new acceleration value from the given number of meters per second squared

Arguments
  • mps2 - Any number-like type, representing a quantity of meters per second squared
pub fn to_mps2(&self) -> T

Returns a copy of this acceleration value in meters per second squared

pub fn from_meters_per_second_squared(meters_per_second_squared: T) -> Self

Returns a new acceleration value from the given number of meters per second squared

Arguments
  • meters_per_second_squared - Any number-like type, representing a quantity of meters per second squared
pub fn to_meters_per_second_squared(&self) -> T

Returns a copy of this acceleration value in meters per second squared

Source

impl<T> Acceleration<T>
where T: NumLike + From<f64>,

pub fn to_mmps2(&self) -> T

Returns a copy of this acceleration value in millimeters per second squared

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_mmps2(mmps2: T) -> Self

Returns a new acceleration value from the given number of millimeters per second squared

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • mmps2 - Any number-like type, representing a quantity of millimeters per second squared
pub fn to_kilometers_per_hour_squared(&self) -> T

Returns a copy of this acceleration value in kilometers per hour squared

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_kilometers_per_hour_squared(kilometers_per_hour_squared: T) -> Self

Returns a new acceleration value from the given number of kilometers per hour squared

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • kilometers_per_hour_squared - Any number-like type, representing a quantity of kilometers per hour squared
pub fn to_kph2(&self) -> T

Returns a copy of this acceleration value in kilometers per hour squared

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_kph2(kph2: T) -> Self

Returns a new acceleration value from the given number of kilometers per hour squared

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • kph2 - Any number-like type, representing a quantity of kilometers per hour squared