pub struct AngularAcceleration<T: NumLike> {
pub radps2: T,
}Expand description
The angular acceleration unit type, defined as radians per second squared in SI units
Fields
radps2: TThe value of this Angular acceleration in radians per second squared
Implementations
Sourceimpl<T> AngularAcceleration<T>where
T: NumLike,
impl<T> AngularAcceleration<T>where
T: NumLike,
Sourcepub fn unit_name() -> &'static str
pub fn unit_name() -> &'static str
Returns the standard unit name of angular acceleration: “radians per second squared”
Sourcepub fn unit_symbol() -> &'static str
pub fn unit_symbol() -> &'static str
Returns the abbreviated name or symbol of angular acceleration: “rad/s²” for radians per second squared
Sourcepub fn from_radps2(radps2: T) -> Self
pub fn from_radps2(radps2: T) -> Self
Returns a new angular acceleration value from the given number of radians per second squared
Arguments
radps2- Any number-like type, representing a quantity of radians per second squared
Sourcepub fn to_radps2(&self) -> T
pub fn to_radps2(&self) -> T
Returns a copy of this angular acceleration value in radians per second squared
Sourcepub fn from_radians_per_second_squared(radians_per_second_squared: T) -> Self
pub fn from_radians_per_second_squared(radians_per_second_squared: T) -> Self
Returns a new angular acceleration value from the given number of radians per second squared
Arguments
radians_per_second_squared- Any number-like type, representing a quantity of radians per second squared
Sourcepub fn to_radians_per_second_squared(&self) -> T
pub fn to_radians_per_second_squared(&self) -> T
Returns a copy of this angular acceleration value in radians per second squared
Sourceimpl<T> AngularAcceleration<T>
impl<T> AngularAcceleration<T>
Sourcepub fn to_degrees_per_second_squared(&self) -> T
pub fn to_degrees_per_second_squared(&self) -> T
Returns a copy of this angular acceleration value in degrees per second squared
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_degrees_per_second_squared(degrees_per_second_squared: T) -> Self
pub fn from_degrees_per_second_squared(degrees_per_second_squared: T) -> Self
Returns a new angular acceleration value from the given number of degrees per second squared
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
degrees_per_second_squared- Any number-like type, representing a quantity of degrees per second squared
Sourcepub fn to_rps2(&self) -> T
pub fn to_rps2(&self) -> T
Returns a copy of this angular acceleration value in revolutions per second squared
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_rps2(rps2: T) -> Self
pub fn from_rps2(rps2: T) -> Self
Returns a new angular acceleration value from the given number of revolutions per second squared
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
rps2- Any number-like type, representing a quantity of revolutions per second squared
Sourcepub fn to_rpm2(&self) -> T
pub fn to_rpm2(&self) -> T
Returns a copy of this angular acceleration value in revolutions per minute squared
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_rpm2(rpm2: T) -> Self
pub fn from_rpm2(rpm2: T) -> Self
Returns a new angular acceleration value from the given number of revolutions per minute squared
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
rpm2- Any number-like type, representing a quantity of revolutions per minute squared
Sourcepub fn to_degps2(&self) -> T
pub fn to_degps2(&self) -> T
Returns a copy of this angular acceleration value in degrees per second squared
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_degps2(degps2: T) -> Self
pub fn from_degps2(degps2: T) -> Self
Returns a new angular acceleration value from the given number of degrees per second squared
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
degps2- Any number-like type, representing a quantity of degrees per second squared
Sourcepub fn to_rph2(&self) -> T
pub fn to_rph2(&self) -> T
Returns a copy of this angular acceleration value in revolutions per hour squared
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_rph2(rph2: T) -> Self
pub fn from_rph2(rph2: T) -> Self
Returns a new angular acceleration value from the given number of revolutions per hour squared
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
rph2- Any number-like type, representing a quantity of revolutions per hour squared