Force

Struct Force 

pub struct Force<T: NumLike> {
    pub N: T,
}
The force unit type, defined as newtons in SI units

Fields

N: T

The value of this Force in newtons

Implementations

Source

impl<T> Force<T>
where T: NumLike,

pub fn unit_name() -> &'static str

Returns the standard unit name of force: “newtons”

pub fn unit_symbol() -> &'static str

Returns the abbreviated name or symbol of force: “N” for newtons

pub fn from_N(N: T) -> Self

Returns a new force value from the given number of newtons

Arguments
  • N - Any number-like type, representing a quantity of newtons
pub fn to_N(&self) -> T

Returns a copy of this force value in newtons

pub fn from_newtons(newtons: T) -> Self

Returns a new force value from the given number of newtons

Arguments
  • newtons - Any number-like type, representing a quantity of newtons
pub fn to_newtons(&self) -> T

Returns a copy of this force value in newtons

Source

impl<T> Force<T>
where T: NumLike + From<f64>,

pub fn to_lb(&self) -> T

Returns a copy of this force value in pounds

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_lb(lb: T) -> Self

Returns a new force value from the given number of pounds

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • lb - Any number-like type, representing a quantity of pounds
pub fn to_kgG(&self) -> T

Returns a copy of this force value in kilogram-force

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_kgG(kgG: T) -> Self

Returns a new force value from the given number of kilogram-force

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • kgG - Any number-like type, representing a quantity of kilogram-force
pub fn to_mN(&self) -> T

Returns a copy of this force value in millinewtons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_mN(mN: T) -> Self

Returns a new force value from the given number of millinewtons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • mN - Any number-like type, representing a quantity of millinewtons
pub fn to_uN(&self) -> T

Returns a copy of this force value in micronewtons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_uN(uN: T) -> Self

Returns a new force value from the given number of micronewtons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • uN - Any number-like type, representing a quantity of micronewtons
pub fn to_nN(&self) -> T

Returns a copy of this force value in nanonewtons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_nN(nN: T) -> Self

Returns a new force value from the given number of nanonewtons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • nN - Any number-like type, representing a quantity of nanonewtons
pub fn to_kN(&self) -> T

Returns a copy of this force value in kilonewtons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_kN(kN: T) -> Self

Returns a new force value from the given number of kilonewtons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • kN - Any number-like type, representing a quantity of kilonewtons
pub fn to_MN(&self) -> T

Returns a copy of this force value in meganewtons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_MN(MN: T) -> Self

Returns a new force value from the given number of meganewtons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • MN - Any number-like type, representing a quantity of meganewtons
pub fn to_GN(&self) -> T

Returns a copy of this force value in giganewtons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_GN(GN: T) -> Self

Returns a new force value from the given number of giganewtons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • GN - Any number-like type, representing a quantity of giganewtons