Frequency

Struct Frequency 

pub struct Frequency<T: NumLike> {
    pub Hz: T,
}
The frequency unit type, defined as hertz in SI units

Fields

Hz: T

The value of this Frequency in hertz

Implementations

Source

impl<T> Frequency<T>
where T: NumLike,

pub fn unit_name() -> &'static str

Returns the standard unit name of frequency: “hertz”

pub fn unit_symbol() -> &'static str

Returns the abbreviated name or symbol of frequency: “Hz” for hertz

pub fn from_Hz(Hz: T) -> Self

Returns a new frequency value from the given number of hertz

Arguments
  • Hz - Any number-like type, representing a quantity of hertz
pub fn to_Hz(&self) -> T

Returns a copy of this frequency value in hertz

pub fn from_hertz(hertz: T) -> Self

Returns a new frequency value from the given number of hertz

Arguments
  • hertz - Any number-like type, representing a quantity of hertz
pub fn to_hertz(&self) -> T

Returns a copy of this frequency value in hertz

Source

impl<T> Frequency<T>
where T: NumLike + From<f64>,

pub fn to_kHz(&self) -> T

Returns a copy of this frequency value in kilohertz

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_kHz(kHz: T) -> Self

Returns a new frequency value from the given number of kilohertz

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • kHz - Any number-like type, representing a quantity of kilohertz
pub fn to_MHz(&self) -> T

Returns a copy of this frequency value in megahertz

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_MHz(MHz: T) -> Self

Returns a new frequency value from the given number of megahertz

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • MHz - Any number-like type, representing a quantity of megahertz
pub fn to_GHz(&self) -> T

Returns a copy of this frequency value in gigahertz

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_GHz(GHz: T) -> Self

Returns a new frequency value from the given number of gigahertz

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • GHz - Any number-like type, representing a quantity of gigahertz
pub fn to_THz(&self) -> T

Returns a copy of this frequency value in terahertz

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_THz(THz: T) -> Self

Returns a new frequency value from the given number of terahertz

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • THz - Any number-like type, representing a quantity of terahertz