InverseAcceleration

Struct InverseAcceleration 

pub struct InverseAcceleration<T: NumLike> {
    pub s2pm: T,
}
The inverse of acceleration unit type, defined as seconds squared per meter in SI units

Fields

s2pm: T

The value of this Inverse acceleration in seconds squared per meter

Implementations

Source

impl<T> InverseAcceleration<T>
where T: NumLike,

pub fn unit_name() -> &'static str

Returns the standard unit name of inverse acceleration: “seconds squared per meter”

pub fn unit_symbol() -> &'static str

Returns the abbreviated name or symbol of inverse acceleration: “s²/m” for seconds squared per meter

pub fn from_s2pm(s2pm: T) -> Self

Returns a new inverse acceleration value from the given number of seconds squared per meter

Arguments
  • s2pm - Any number-like type, representing a quantity of seconds squared per meter
pub fn to_s2pm(&self) -> T

Returns a copy of this inverse acceleration value in seconds squared per meter

pub fn from_seconds_squared_per_meter(seconds_squared_per_meter: T) -> Self

Returns a new inverse acceleration value from the given number of seconds squared per meter

Arguments
  • seconds_squared_per_meter - Any number-like type, representing a quantity of seconds squared per meter
pub fn to_seconds_squared_per_meter(&self) -> T

Returns a copy of this inverse acceleration value in seconds squared per meter

Source

impl<T> InverseAcceleration<T>
where T: NumLike + From<f64>,

pub fn to_s2pmm(&self) -> T

Returns a copy of this inverse acceleration value in seconds squared per millimeter

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_s2pmm(s2pmm: T) -> Self

Returns a new inverse acceleration value from the given number of seconds squared per millimeter

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • s2pmm - Any number-like type, representing a quantity of seconds squared per millimeter
pub fn to_hours_squared_per_kilometers(&self) -> T

Returns a copy of this inverse acceleration value in hours squared per kilometer

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_hours_squared_per_kilometers( hours_squared_per_kilometers: T, ) -> Self

Returns a new inverse acceleration value from the given number of hours squared per kilometer

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • hours_squared_per_kilometers - Any number-like type, representing a quantity of hours squared per kilometer
pub fn to_hr2_per_km(&self) -> T

Returns a copy of this inverse acceleration value in hours squared per kilometer

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_hr2_per_km(hr2_per_km: T) -> Self

Returns a new inverse acceleration value from the given number of hours squared per kilometer

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • hr2_per_km - Any number-like type, representing a quantity of hours squared per kilometer