InverseAngularVelocity

Struct InverseAngularVelocity 

pub struct InverseAngularVelocity<T: NumLike> {
    pub s_per_rad: T,
}
The inverse of angular velocity unit type, defined as seconds per radian in SI units

Fields

s_per_rad: T

The value of this Inverse angular velocity in seconds per radian

Implementations

Source

impl<T> InverseAngularVelocity<T>
where T: NumLike,

pub fn unit_name() -> &'static str

Returns the standard unit name of inverse angular velocity: “seconds per radian”

pub fn unit_symbol() -> &'static str

Returns the abbreviated name or symbol of inverse angular velocity: “s/rad” for seconds per radian

pub fn from_s_per_rad(s_per_rad: T) -> Self

Returns a new inverse angular velocity value from the given number of seconds per radian

Arguments
  • s_per_rad - Any number-like type, representing a quantity of seconds per radian
pub fn to_s_per_rad(&self) -> T

Returns a copy of this inverse angular velocity value in seconds per radian

pub fn from_seconds_per_radian(seconds_per_radian: T) -> Self

Returns a new inverse angular velocity value from the given number of seconds per radian

Arguments
  • seconds_per_radian - Any number-like type, representing a quantity of seconds per radian
pub fn to_seconds_per_radian(&self) -> T

Returns a copy of this inverse angular velocity value in seconds per radian

Source

impl<T> InverseAngularVelocity<T>
where T: NumLike + From<f64>,

pub fn to_seconds_per_degree(&self) -> T

Returns a copy of this inverse angular velocity value in seconds per degree

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_seconds_per_degree(seconds_per_degree: T) -> Self

Returns a new inverse angular velocity value from the given number of seconds per degree

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • seconds_per_degree - Any number-like type, representing a quantity of seconds per degree
pub fn to_s_per_deg(&self) -> T

Returns a copy of this inverse angular velocity value in seconds per degree

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_s_per_deg(s_per_deg: T) -> Self

Returns a new inverse angular velocity value from the given number of seconds per degree

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • s_per_deg - Any number-like type, representing a quantity of seconds per degree
pub fn to_spr(&self) -> T

Returns a copy of this inverse angular velocity value in seconds per revolution

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_spr(spr: T) -> Self

Returns a new inverse angular velocity value from the given number of seconds per revolution

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • spr - Any number-like type, representing a quantity of seconds per revolution
pub fn to_mpr(&self) -> T

Returns a copy of this inverse angular velocity value in minutes per revolution

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_mpr(mpr: T) -> Self

Returns a new inverse angular velocity value from the given number of minutes per revolution

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • mpr - Any number-like type, representing a quantity of minutes per revolution
pub fn to_hpr(&self) -> T

Returns a copy of this inverse angular velocity value in hours per revolution

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_hpr(hpr: T) -> Self

Returns a new inverse angular velocity value from the given number of hours per revolution

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • hpr - Any number-like type, representing a quantity of hours per revolution