InverseForce

Struct InverseForce 

pub struct InverseForce<T: NumLike> {
    pub per_N: T,
}
The inverse of force unit type, defined as inverse newtons in SI units

Fields

per_N: T

The value of this Inverse force in inverse newtons

Implementations

Source

impl<T> InverseForce<T>
where T: NumLike,

pub fn unit_name() -> &'static str

Returns the standard unit name of inverse force: “inverse newtons”

pub fn unit_symbol() -> &'static str

Returns the abbreviated name or symbol of inverse force: “1/N” for inverse newtons

pub fn from_per_N(per_N: T) -> Self

Returns a new inverse force value from the given number of inverse newtons

Arguments
  • per_N - Any number-like type, representing a quantity of inverse newtons
pub fn to_per_N(&self) -> T

Returns a copy of this inverse force value in inverse newtons

pub fn from_per_newton(per_newton: T) -> Self

Returns a new inverse force value from the given number of inverse newtons

Arguments
  • per_newton - Any number-like type, representing a quantity of inverse newtons
pub fn to_per_newton(&self) -> T

Returns a copy of this inverse force value in inverse newtons

Source

impl<T> InverseForce<T>
where T: NumLike + From<f64>,

pub fn to_per_lb(&self) -> T

Returns a copy of this inverse force value in inverse pounds

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_lb(per_lb: T) -> Self

Returns a new inverse force value from the given number of inverse pounds

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_lb - Any number-like type, representing a quantity of inverse pounds
pub fn to_per_kgG(&self) -> T

Returns a copy of this inverse force value in inverse kilogram-force

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_kgG(per_kgG: T) -> Self

Returns a new inverse force value from the given number of inverse kilogram-force

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_kgG - Any number-like type, representing a quantity of inverse kilogram-force
pub fn to_per_mN(&self) -> T

Returns a copy of this inverse force value in inverse millinewtons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_mN(per_mN: T) -> Self

Returns a new inverse force value from the given number of inverse millinewtons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_mN - Any number-like type, representing a quantity of inverse millinewtons
pub fn to_per_uN(&self) -> T

Returns a copy of this inverse force value in inverse micronewtons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_uN(per_uN: T) -> Self

Returns a new inverse force value from the given number of inverse micronewtons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_uN - Any number-like type, representing a quantity of inverse micronewtons
pub fn to_per_nN(&self) -> T

Returns a copy of this inverse force value in inverse nanonewtons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_nN(per_nN: T) -> Self

Returns a new inverse force value from the given number of inverse nanonewtons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_nN - Any number-like type, representing a quantity of inverse nanonewtons
pub fn to_per_kN(&self) -> T

Returns a copy of this inverse force value in inverse kilonewtons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_kN(per_kN: T) -> Self

Returns a new inverse force value from the given number of inverse kilonewtons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_kN - Any number-like type, representing a quantity of inverse kilonewtons
pub fn to_per_MN(&self) -> T

Returns a copy of this inverse force value in inverse meganewtons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_MN(per_MN: T) -> Self

Returns a new inverse force value from the given number of inverse meganewtons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_MN - Any number-like type, representing a quantity of inverse meganewtons
pub fn to_per_GN(&self) -> T

Returns a copy of this inverse force value in inverse giganewtons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_per_GN(per_GN: T) -> Self

Returns a new inverse force value from the given number of inverse giganewtons

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • per_GN - Any number-like type, representing a quantity of inverse giganewtons