TimePerDistance

Struct TimePerDistance 

pub struct TimePerDistance<T: NumLike> {
    pub spm: T,
}
The inverse of velocity unit type, defined as seconds per meter in SI units

Fields

spm: T

The value of this Time per distance in seconds per meter

Implementations

Source

impl<T> TimePerDistance<T>
where T: NumLike,

pub fn unit_name() -> &'static str

Returns the standard unit name of time per distance: “seconds per meter”

pub fn unit_symbol() -> &'static str

Returns the abbreviated name or symbol of time per distance: “s/m” for seconds per meter

pub fn from_spm(spm: T) -> Self

Returns a new time per distance value from the given number of seconds per meter

Arguments
  • spm - Any number-like type, representing a quantity of seconds per meter
pub fn to_spm(&self) -> T

Returns a copy of this time per distance value in seconds per meter

pub fn from_seconds_per_meter(seconds_per_meter: T) -> Self

Returns a new time per distance value from the given number of seconds per meter

Arguments
  • seconds_per_meter - Any number-like type, representing a quantity of seconds per meter
pub fn to_seconds_per_meter(&self) -> T

Returns a copy of this time per distance value in seconds per meter

Source

impl<T> TimePerDistance<T>
where T: NumLike + From<f64>,

pub fn to_s_per_cm(&self) -> T

Returns a copy of this time per distance value in seconds per centimeter

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_s_per_cm(s_per_cm: T) -> Self

Returns a new time per distance value from the given number of seconds per centimeter

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • s_per_cm - Any number-like type, representing a quantity of seconds per centimeter
pub fn to_s_per_mm(&self) -> T

Returns a copy of this time per distance value in seconds per millimeter

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_s_per_mm(s_per_mm: T) -> Self

Returns a new time per distance value from the given number of seconds per millimeter

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • s_per_mm - Any number-like type, representing a quantity of seconds per millimeter
pub fn to_hr_per_km(&self) -> T

Returns a copy of this time per distance value in hours per kilometer

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_hr_per_km(hr_per_km: T) -> Self

Returns a new time per distance value from the given number of hours per kilometer

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • hr_per_km - Any number-like type, representing a quantity of hours per kilometer
pub fn to_hr_per_mi(&self) -> T

Returns a copy of this time per distance value in hours per mile

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_hr_per_mi(hr_per_mi: T) -> Self

Returns a new time per distance value from the given number of hours per mile

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • hr_per_mi - Any number-like type, representing a quantity of hours per mile