Torque

Struct Torque 

pub struct Torque<T: NumLike> {
    pub Nm: T,
}
The torque unit type, defined as newton meters in SI units

Fields

Nm: T

The value of this Torque in newton meters

Implementations

Source

impl<T> Torque<T>
where T: NumLike,

pub fn unit_name() -> &'static str

Returns the standard unit name of torque: “newton meters”

pub fn unit_symbol() -> &'static str

Returns the abbreviated name or symbol of torque: “Nm” for newton meters

pub fn from_Nm(Nm: T) -> Self

Returns a new torque value from the given number of newton meters

Arguments
  • Nm - Any number-like type, representing a quantity of newton meters
pub fn to_Nm(&self) -> T

Returns a copy of this torque value in newton meters

pub fn from_newton_meters(newton_meters: T) -> Self

Returns a new torque value from the given number of newton meters

Arguments
  • newton_meters - Any number-like type, representing a quantity of newton meters
pub fn to_newton_meters(&self) -> T

Returns a copy of this torque value in newton meters

Source

impl<T> Torque<T>
where T: NumLike + From<f64>,

pub fn to_ftlb(&self) -> T

Returns a copy of this torque value in foot-pounds

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_ftlb(ftlb: T) -> Self

Returns a new torque value from the given number of foot-pounds

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • ftlb - Any number-like type, representing a quantity of foot-pounds