pub struct AbsorbedDose<T: NumLike> {
pub Gy: T,
}Expand description
The absorbed radiation dose unit type, defined as grays in SI units
Fields
Gy: TThe value of this Absorbed dose in grays
Implementations
Sourceimpl<T> AbsorbedDose<T>where
T: NumLike,
impl<T> AbsorbedDose<T>where
T: NumLike,
Sourcepub fn unit_symbol() -> &'static str
pub fn unit_symbol() -> &'static str
Returns the abbreviated name or symbol of absorbed dose: “Gy” for grays
Sourcepub fn from_Gy(Gy: T) -> Self
pub fn from_Gy(Gy: T) -> Self
Returns a new absorbed dose value from the given number of grays
Arguments
Gy- Any number-like type, representing a quantity of grays
Sourcepub fn from_grays(grays: T) -> Self
pub fn from_grays(grays: T) -> Self
Returns a new absorbed dose value from the given number of grays
Arguments
grays- Any number-like type, representing a quantity of grays
Sourceimpl<T> AbsorbedDose<T>
impl<T> AbsorbedDose<T>
Sourcepub fn to_mGy(&self) -> T
pub fn to_mGy(&self) -> T
Returns a copy of this absorbed dose value in milligrays
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_mGy(mGy: T) -> Self
pub fn from_mGy(mGy: T) -> Self
Returns a new absorbed dose value from the given number of milligrays
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
mGy- Any number-like type, representing a quantity of milligrays
Sourcepub fn to_uGy(&self) -> T
pub fn to_uGy(&self) -> T
Returns a copy of this absorbed dose value in micrograys
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_uGy(uGy: T) -> Self
pub fn from_uGy(uGy: T) -> Self
Returns a new absorbed dose value from the given number of micrograys
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
uGy- Any number-like type, representing a quantity of micrograys
Sourcepub fn to_nGy(&self) -> T
pub fn to_nGy(&self) -> T
Returns a copy of this absorbed dose value in nanograys
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_nGy(nGy: T) -> Self
pub fn from_nGy(nGy: T) -> Self
Returns a new absorbed dose value from the given number of nanograys
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
nGy- Any number-like type, representing a quantity of nanograys
Sourcepub fn to_kGy(&self) -> T
pub fn to_kGy(&self) -> T
Returns a copy of this absorbed dose value in kilograys
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_kGy(kGy: T) -> Self
pub fn from_kGy(kGy: T) -> Self
Returns a new absorbed dose value from the given number of kilograys
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
kGy- Any number-like type, representing a quantity of kilograys
Sourcepub fn to_MGy(&self) -> T
pub fn to_MGy(&self) -> T
Returns a copy of this absorbed dose value in megagrays
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_MGy(MGy: T) -> Self
pub fn from_MGy(MGy: T) -> Self
Returns a new absorbed dose value from the given number of megagrays
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
MGy- Any number-like type, representing a quantity of megagrays
Sourcepub fn to_GGy(&self) -> T
pub fn to_GGy(&self) -> T
Returns a copy of this absorbed dose value in gigagrays
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_GGy(GGy: T) -> Self
pub fn from_GGy(GGy: T) -> Self
Returns a new absorbed dose value from the given number of gigagrays
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
GGy- Any number-like type, representing a quantity of gigagrays
Sourcepub fn to_rad(&self) -> T
pub fn to_rad(&self) -> T
Returns a copy of this absorbed dose value in rads
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_rad(rad: T) -> Self
pub fn from_rad(rad: T) -> Self
Returns a new absorbed dose value from the given number of rads
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
rad- Any number-like type, representing a quantity of rads
Sourcepub fn to_krad(&self) -> T
pub fn to_krad(&self) -> T
Returns a copy of this absorbed dose value in kilorads
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_krad(krad: T) -> Self
pub fn from_krad(krad: T) -> Self
Returns a new absorbed dose value from the given number of kilorads
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
krad- Any number-like type, representing a quantity of kilorads
Sourcepub fn to_mrad(&self) -> T
pub fn to_mrad(&self) -> T
Returns a copy of this absorbed dose value in millirads
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_mrad(mrad: T) -> Self
pub fn from_mrad(mrad: T) -> Self
Returns a new absorbed dose value from the given number of millirads
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
mrad- Any number-like type, representing a quantity of millirads
Sourcepub fn to_urad(&self) -> T
pub fn to_urad(&self) -> T
Returns a copy of this absorbed dose value in microrads
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_urad(urad: T) -> Self
pub fn from_urad(urad: T) -> Self
Returns a new absorbed dose value from the given number of microrads
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
urad- Any number-like type, representing a quantity of microrads