DoseEquivalent

Struct DoseEquivalent 

pub struct DoseEquivalent<T: NumLike> {
    pub Sv: T,
}
The radiation dose equivalent unit type, defined as sieverts in SI units

Fields

Sv: T

The value of this Dose equivalent in sieverts

Implementations

Source

impl<T> DoseEquivalent<T>
where T: NumLike,

pub fn unit_name() -> &'static str

Returns the standard unit name of dose equivalent: “sieverts”

pub fn unit_symbol() -> &'static str

Returns the abbreviated name or symbol of dose equivalent: “Sv” for sieverts

pub fn from_Sv(Sv: T) -> Self

Returns a new dose equivalent value from the given number of sieverts

Arguments
  • Sv - Any number-like type, representing a quantity of sieverts
pub fn to_Sv(&self) -> T

Returns a copy of this dose equivalent value in sieverts

pub fn from_sieverts(sieverts: T) -> Self

Returns a new dose equivalent value from the given number of sieverts

Arguments
  • sieverts - Any number-like type, representing a quantity of sieverts
pub fn to_sieverts(&self) -> T

Returns a copy of this dose equivalent value in sieverts

Source

impl<T> DoseEquivalent<T>
where T: NumLike + From<f64>,

pub fn to_mSv(&self) -> T

Returns a copy of this dose equivalent value in millisieverts

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_mSv(mSv: T) -> Self

Returns a new dose equivalent value from the given number of millisieverts

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • mSv - Any number-like type, representing a quantity of millisieverts
pub fn to_uSv(&self) -> T

Returns a copy of this dose equivalent value in microsieverts

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_uSv(uSv: T) -> Self

Returns a new dose equivalent value from the given number of microsieverts

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • uSv - Any number-like type, representing a quantity of microsieverts
pub fn to_nSv(&self) -> T

Returns a copy of this dose equivalent value in nanosieverts

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_nSv(nSv: T) -> Self

Returns a new dose equivalent value from the given number of nanosieverts

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • nSv - Any number-like type, representing a quantity of nanosieverts
pub fn to_kSv(&self) -> T

Returns a copy of this dose equivalent value in kilosieverts

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_kSv(kSv: T) -> Self

Returns a new dose equivalent value from the given number of kilosieverts

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • kSv - Any number-like type, representing a quantity of kilosieverts
pub fn to_MSv(&self) -> T

Returns a copy of this dose equivalent value in megasieverts

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_MSv(MSv: T) -> Self

Returns a new dose equivalent value from the given number of megasieverts

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • MSv - Any number-like type, representing a quantity of megasieverts
pub fn to_GSv(&self) -> T

Returns a copy of this dose equivalent value in gigasieverts

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_GSv(GSv: T) -> Self

Returns a new dose equivalent value from the given number of gigasieverts

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • GSv - Any number-like type, representing a quantity of gigasieverts
pub fn to_rem(&self) -> T

Returns a copy of this dose equivalent value in roentgen equivalent man

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_rem(rem: T) -> Self

Returns a new dose equivalent value from the given number of roentgen equivalent man

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • rem - Any number-like type, representing a quantity of roentgen equivalent man
pub fn to_mrem(&self) -> T

Returns a copy of this dose equivalent value in milli-roentgen equivalents

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_mrem(mrem: T) -> Self

Returns a new dose equivalent value from the given number of milli-roentgen equivalents

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • mrem - Any number-like type, representing a quantity of milli-roentgen equivalents
pub fn to_krem(&self) -> T

Returns a copy of this dose equivalent value in kilo-roentgen equivalents

Note: This method is not available for f32 and other number types lacking the From<f64> trait

pub fn from_krem(krem: T) -> Self

Returns a new dose equivalent value from the given number of kilo-roentgen equivalents

Note: This method is not available for f32 and other number types lacking the From<f64> trait

Arguments
  • krem - Any number-like type, representing a quantity of kilo-roentgen equivalents