pub struct Amount<T: NumLike> {
pub mol: T,
}Expand description
The amount unit type, defined as moles in SI units
Fields
mol: TThe value of this Amount in moles
Implementations
Sourceimpl<T> Amount<T>where
T: NumLike,
impl<T> Amount<T>where
T: NumLike,
Sourcepub fn unit_symbol() -> &'static str
pub fn unit_symbol() -> &'static str
Returns the abbreviated name or symbol of amount: “mol” for moles
Sourcepub fn from_moles(moles: T) -> Self
pub fn from_moles(moles: T) -> Self
Returns a new amount value from the given number of moles
Arguments
moles- Any number-like type, representing a quantity of moles
Sourceimpl<T> Amount<T>
impl<T> Amount<T>
Sourcepub fn to_count(&self) -> T
pub fn to_count(&self) -> T
Returns a copy of this amount value in count
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_count(count: T) -> Self
pub fn from_count(count: T) -> Self
Returns a new amount value from the given number of count
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
count- Any number-like type, representing a quantity of count
Sourcepub fn to_mmol(&self) -> T
pub fn to_mmol(&self) -> T
Returns a copy of this amount value in millimoles
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_mmol(mmol: T) -> Self
pub fn from_mmol(mmol: T) -> Self
Returns a new amount value from the given number of millimoles
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
mmol- Any number-like type, representing a quantity of millimoles
Sourcepub fn to_umol(&self) -> T
pub fn to_umol(&self) -> T
Returns a copy of this amount value in micromoles
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_umol(umol: T) -> Self
pub fn from_umol(umol: T) -> Self
Returns a new amount value from the given number of micromoles
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
umol- Any number-like type, representing a quantity of micromoles
Sourcepub fn to_nmol(&self) -> T
pub fn to_nmol(&self) -> T
Returns a copy of this amount value in nanomoles
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_nmol(nmol: T) -> Self
pub fn from_nmol(nmol: T) -> Self
Returns a new amount value from the given number of nanomoles
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
nmol- Any number-like type, representing a quantity of nanomoles