pub struct InverseLuminosity<T: NumLike> {
pub per_cd: T,
}Expand description
The inverse of luminosity unit type, defined as inverse candela in SI units
Fields
per_cd: TThe value of this Inverse luminosity in inverse candela
Implementations
Sourceimpl<T> InverseLuminosity<T>where
T: NumLike,
impl<T> InverseLuminosity<T>where
T: NumLike,
Sourcepub fn unit_name() -> &'static str
pub fn unit_name() -> &'static str
Returns the standard unit name of inverse luminosity: “inverse candela”
Sourcepub fn unit_symbol() -> &'static str
pub fn unit_symbol() -> &'static str
Returns the abbreviated name or symbol of inverse luminosity: “1/cd” for inverse candela
Sourcepub fn from_per_cd(per_cd: T) -> Self
pub fn from_per_cd(per_cd: T) -> Self
Returns a new inverse luminosity value from the given number of inverse candela
Arguments
per_cd- Any number-like type, representing a quantity of inverse candela
Sourcepub fn to_per_cd(&self) -> T
pub fn to_per_cd(&self) -> T
Returns a copy of this inverse luminosity value in inverse candela
Sourcepub fn from_per_candela(per_candela: T) -> Self
pub fn from_per_candela(per_candela: T) -> Self
Returns a new inverse luminosity value from the given number of inverse candela
Arguments
per_candela- Any number-like type, representing a quantity of inverse candela
Sourcepub fn to_per_candela(&self) -> T
pub fn to_per_candela(&self) -> T
Returns a copy of this inverse luminosity value in inverse candela
Sourceimpl<T> InverseLuminosity<T>
impl<T> InverseLuminosity<T>
Sourcepub fn to_per_mcd(&self) -> T
pub fn to_per_mcd(&self) -> T
Returns a copy of this inverse luminosity value in inverse millicandela
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_per_mcd(per_mcd: T) -> Self
pub fn from_per_mcd(per_mcd: T) -> Self
Returns a new inverse luminosity value from the given number of inverse millicandela
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
per_mcd- Any number-like type, representing a quantity of inverse millicandela
Sourcepub fn to_per_ucd(&self) -> T
pub fn to_per_ucd(&self) -> T
Returns a copy of this inverse luminosity value in inverse microcandela
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_per_ucd(per_ucd: T) -> Self
pub fn from_per_ucd(per_ucd: T) -> Self
Returns a new inverse luminosity value from the given number of inverse microcandela
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
per_ucd- Any number-like type, representing a quantity of inverse microcandela
Sourcepub fn to_per_ncd(&self) -> T
pub fn to_per_ncd(&self) -> T
Returns a copy of this inverse luminosity value in inverse nanocandela
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_per_ncd(per_ncd: T) -> Self
pub fn from_per_ncd(per_ncd: T) -> Self
Returns a new inverse luminosity value from the given number of inverse nanocandela
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
per_ncd- Any number-like type, representing a quantity of inverse nanocandela
Sourcepub fn to_per_kcd(&self) -> T
pub fn to_per_kcd(&self) -> T
Returns a copy of this inverse luminosity value in inverse kilocandela
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_per_kcd(per_kcd: T) -> Self
pub fn from_per_kcd(per_kcd: T) -> Self
Returns a new inverse luminosity value from the given number of inverse kilocandela
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
per_kcd- Any number-like type, representing a quantity of inverse kilocandela
Sourcepub fn to_per_Mcd(&self) -> T
pub fn to_per_Mcd(&self) -> T
Returns a copy of this inverse luminosity value in inverse megacandela
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_per_Mcd(per_Mcd: T) -> Self
pub fn from_per_Mcd(per_Mcd: T) -> Self
Returns a new inverse luminosity value from the given number of inverse megacandela
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
per_Mcd- Any number-like type, representing a quantity of inverse megacandela
Sourcepub fn to_per_Gcd(&self) -> T
pub fn to_per_Gcd(&self) -> T
Returns a copy of this inverse luminosity value in inverse gigacandela
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_per_Gcd(per_Gcd: T) -> Self
pub fn from_per_Gcd(per_Gcd: T) -> Self
Returns a new inverse luminosity value from the given number of inverse gigacandela
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
per_Gcd- Any number-like type, representing a quantity of inverse gigacandela