pub struct Capacitance<T: NumLike> {
pub F: T,
}Expand description
The electrical capacitance unit type, defined as farads in SI units
Fields
F: TThe value of this Electrical capacitance in farads
Implementations
Sourceimpl<T> Capacitance<T>where
T: NumLike,
impl<T> Capacitance<T>where
T: NumLike,
Sourcepub fn unit_name() -> &'static str
pub fn unit_name() -> &'static str
Returns the standard unit name of electrical capacitance: “farads”
Sourcepub fn unit_symbol() -> &'static str
pub fn unit_symbol() -> &'static str
Returns the abbreviated name or symbol of electrical capacitance: “F” for farads
Sourcepub fn from_F(F: T) -> Self
pub fn from_F(F: T) -> Self
Returns a new electrical capacitance value from the given number of farads
Arguments
F- Any number-like type, representing a quantity of farads
Sourcepub fn from_farads(farads: T) -> Self
pub fn from_farads(farads: T) -> Self
Returns a new electrical capacitance value from the given number of farads
Arguments
farads- Any number-like type, representing a quantity of farads
Sourceimpl<T> Capacitance<T>
impl<T> Capacitance<T>
Sourcepub fn to_mF(&self) -> T
pub fn to_mF(&self) -> T
Returns a copy of this electrical capacitance value in millifarads
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_mF(mF: T) -> Self
pub fn from_mF(mF: T) -> Self
Returns a new electrical capacitance value from the given number of millifarads
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
mF- Any number-like type, representing a quantity of millifarads
Sourcepub fn to_uF(&self) -> T
pub fn to_uF(&self) -> T
Returns a copy of this electrical capacitance value in microfarads
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_uF(uF: T) -> Self
pub fn from_uF(uF: T) -> Self
Returns a new electrical capacitance value from the given number of microfarads
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
uF- Any number-like type, representing a quantity of microfarads
Sourcepub fn to_nF(&self) -> T
pub fn to_nF(&self) -> T
Returns a copy of this electrical capacitance value in nanofarads
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_nF(nF: T) -> Self
pub fn from_nF(nF: T) -> Self
Returns a new electrical capacitance value from the given number of nanofarads
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
nF- Any number-like type, representing a quantity of nanofarads
Sourcepub fn to_pF(&self) -> T
pub fn to_pF(&self) -> T
Returns a copy of this electrical capacitance value in picofarads
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_pF(pF: T) -> Self
pub fn from_pF(pF: T) -> Self
Returns a new electrical capacitance value from the given number of picofarads
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
pF- Any number-like type, representing a quantity of picofarads
Sourcepub fn to_kF(&self) -> T
pub fn to_kF(&self) -> T
Returns a copy of this electrical capacitance value in kilofarads
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_kF(kF: T) -> Self
pub fn from_kF(kF: T) -> Self
Returns a new electrical capacitance value from the given number of kilofarads
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
kF- Any number-like type, representing a quantity of kilofarads
Sourcepub fn to_MF(&self) -> T
pub fn to_MF(&self) -> T
Returns a copy of this electrical capacitance value in megafarads
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_MF(MF: T) -> Self
pub fn from_MF(MF: T) -> Self
Returns a new electrical capacitance value from the given number of megafarads
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
MF- Any number-like type, representing a quantity of megafarads