pub struct Force<T: NumLike> {
pub N: T,
}Expand description
The force unit type, defined as newtons in SI units
Fields
N: TThe value of this Force in newtons
Implementations
Sourceimpl<T> Force<T>where
T: NumLike,
impl<T> Force<T>where
T: NumLike,
Sourcepub fn unit_symbol() -> &'static str
pub fn unit_symbol() -> &'static str
Returns the abbreviated name or symbol of force: “N” for newtons
Sourcepub fn from_N(N: T) -> Self
pub fn from_N(N: T) -> Self
Returns a new force value from the given number of newtons
Arguments
N- Any number-like type, representing a quantity of newtons
Sourcepub fn from_newtons(newtons: T) -> Self
pub fn from_newtons(newtons: T) -> Self
Returns a new force value from the given number of newtons
Arguments
newtons- Any number-like type, representing a quantity of newtons
Sourcepub fn to_newtons(&self) -> T
pub fn to_newtons(&self) -> T
Returns a copy of this force value in newtons
Sourceimpl<T> Force<T>
impl<T> Force<T>
Sourcepub fn to_lb(&self) -> T
pub fn to_lb(&self) -> T
Returns a copy of this force value in pounds
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_lb(lb: T) -> Self
pub fn from_lb(lb: T) -> Self
Returns a new force value from the given number of pounds
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
lb- Any number-like type, representing a quantity of pounds
Sourcepub fn to_kgG(&self) -> T
pub fn to_kgG(&self) -> T
Returns a copy of this force value in kilogram-force
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_kgG(kgG: T) -> Self
pub fn from_kgG(kgG: T) -> Self
Returns a new force value from the given number of kilogram-force
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
kgG- Any number-like type, representing a quantity of kilogram-force
Sourcepub fn to_mN(&self) -> T
pub fn to_mN(&self) -> T
Returns a copy of this force value in millinewtons
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_mN(mN: T) -> Self
pub fn from_mN(mN: T) -> Self
Returns a new force value from the given number of millinewtons
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
mN- Any number-like type, representing a quantity of millinewtons
Sourcepub fn to_uN(&self) -> T
pub fn to_uN(&self) -> T
Returns a copy of this force value in micronewtons
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_uN(uN: T) -> Self
pub fn from_uN(uN: T) -> Self
Returns a new force value from the given number of micronewtons
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
uN- Any number-like type, representing a quantity of micronewtons
Sourcepub fn to_nN(&self) -> T
pub fn to_nN(&self) -> T
Returns a copy of this force value in nanonewtons
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_nN(nN: T) -> Self
pub fn from_nN(nN: T) -> Self
Returns a new force value from the given number of nanonewtons
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
nN- Any number-like type, representing a quantity of nanonewtons
Sourcepub fn to_kN(&self) -> T
pub fn to_kN(&self) -> T
Returns a copy of this force value in kilonewtons
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_kN(kN: T) -> Self
pub fn from_kN(kN: T) -> Self
Returns a new force value from the given number of kilonewtons
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
kN- Any number-like type, representing a quantity of kilonewtons
Sourcepub fn to_MN(&self) -> T
pub fn to_MN(&self) -> T
Returns a copy of this force value in meganewtons
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Sourcepub fn from_MN(MN: T) -> Self
pub fn from_MN(MN: T) -> Self
Returns a new force value from the given number of meganewtons
Note: This method is not available for f32 and other number types lacking the From<f64> trait
Arguments
MN- Any number-like type, representing a quantity of meganewtons